package xmdv.dataproc;



/***********************************************************

**  CopyRight (c) by Xmdv Group, CS Department of WPI, 2003

**  All Rights Reserved.

**

**  Author: Jing Yang

**  Date:   06/2003

***********************************************************/



/**

 * An instance of this class defines an 1-D brush.

 * A Brush1D contains a double maximum and a double minimum value, 

 * the maximum value must be larger or equal to the minimum value.

 * The maximum value must be less or equal to 1, 

 * the minimum value must be larger or equal to 0.

 *

 * @author  Jing Yang

 * @version v1.0

 */

public class Brush1D {

    // Variables declaration

    protected double max, min;

    // End of variables declaration

    

    /** Creates new Brush1D */

    public Brush1D() {

        max = 0.75; 

        min = 0.25;

    }

    

    /**

     * Returns a Brush1D that copys this Brush1D

     * @return a Brush1D that copys this Brush1D

     */

    public Brush1D copy() {

        Brush1D newBrush1D = new Brush1D();

        newBrush1D.setMax(max);

        newBrush1D.setMin(min);

        

        return newBrush1D;

    }

    

    /**

     * Gets the maximum value of this Brush1D.  

     * @return the maximum value of this Brush1D

     */

    public double getMax() {

        return max;

    }

    

    /**

     * Gets the minimum value of this Brush1D.  

     * @return the minimum value of this Brush1D

     */

    public double getMin() {

        return min;

    }

    

    /**

     * Gets the center value between the minimum and maximum value.  

     * @return the center value between the minimum and maximum value

     */

    public double getCenter() {

        return (max + min)/2;

    }

    

    /**

     * Gets half of the distance between the minimum and maximum value.  

     * @return half of the distance between the minimum and maximum value

     */

    public double getRadius() {

        return (max - min)/2;

    }

    

    /**

     * Set the maximum value of this Brush1D

     * @param max the maximum value to be set. 

     * If max is larger than 1, the maximum value will be set to 1. 

     * If max is smaller than the minimum value of this Brush1D, the maximum value will be set to the minimum value. 

     */

    public void setMax(double max) {

        if (max > 1)

            max = 1;

        if (max < min)

            max = min;

        this.max = max;

    }

    

    /**

     * Set the minimum value of this Brush1D

     * @param min the minimum value to be set. 

     * If min is smaller than 0, the minimum value will be set to 0. 

     * If min is larger than the maximum value of this Brush1D, the minimum value will be set to the maximum value. 

     */

    public void setMin(double min) {

        if (min < 0)

            min = 0;

        if (min > max)

            min = max;

        this.min = min;

    }

    

    /**

     * Set the minimum value and the maximum value of this Brush1D

     * @param min the minimum value to be set. 

     * @param max the maximum value to be set. 

     */

    public void setMinMax(double min, double max) {

        setMax(1);

        setMin(min);

        setMax(max);

    }

    

    /**

     * Shifs this Brush1D

     * @param shiftValue value to be added to the maximum and minimum value of this Brush1D.

     * if the shifted maximum or minimum value will be out of range, the shift value will 

     * be auto adjusted to fit the range.

     */

    public void shift(double shiftValue) {

        if (max + shiftValue > 1)

            shiftValue = 1 - max;

        if (min + shiftValue < 0)

            shiftValue = 0 - min;

            

        max += shiftValue;

        min += shiftValue;

    }

}